/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/



#ifndef __CMAINMENU_H__
#define __CMAINMENU_H__

#include <e32base.h>
#include <etel3rdparty.h>


#include "CISVAPIAsync.h"

#include "CBaseMenuAsync.h"

// Active objects
#include "CPhoneId.h"
#include "CFlightModeInfo.h"
#include "CNetworkRegInfo.h"
#include "CDialCall.h"
#include "CSendDTMF.h"
#include "CHangup.h"
#include "CLineStatus.h"
#include "CCallStatus.h"


_LIT(KPhoneIdMsg, "Phone Id:\n");
_LIT(KNetworkRegMsg, "Network Registration Status:\n");
_LIT(KMenuMsg, "*~Auto DTMF Dialler~*\nPress E to exit\n");
_LIT(KHangupMsg, "Press H to Hangup the active Call\n");
_LIT(KDialMsg, "Press D to Dial a Call\n");
_LIT(KDTMFQuestion, "How would you like to send the DTMF string?\n" );
_LIT(KiSingleString, "Press S to Send Predefinied DTMF string\n");
_LIT(KAsChar, "Press Required numbers then # to specify the DTMF string with Keypresses\n");

_LIT(KTheNumber, "01123581321");

/**
Provides the required functionality for the application to run correctly; owns 
active objects required to make ETel3rdParty calls.
*/
class CMainMenu : public CBaseMenuAsync
	{
	// Methods
public:
	static CMainMenu* NewLC(CConsoleBase& aConsole);
	~CMainMenu();

	void ExecComplete(TTelISVExampleType aDerivedType);
	void ExecNotify(TTelISVExampleType aDerivedType);

private:
	CMainMenu(CConsoleBase& aConsole);
	void ConstructL();

	void RunL();	// Handles key presses
	void DoCancel();

	// Data
private:
	// Owned active objects
	/**
	Active object which demonstrates the use of CTelephony::GetPhoneId()
	*/
	CISVAPIAsync* iPhoneId;
	/**
	Active object which demonstrates the use of CTelephony::GetFlightMode()
	*/
	CISVAPIAsync* iFlightModeInfo;
	/**
	Active object which demonstrates the use of CTelephony::GetNetworkRegistrationStatus()
	*/
	CISVAPIAsync* iNetworkRegInfo;
	/**
	Active object which demonstrates the use of CTelephony::SendDTMFTones()
	*/
	CISVAPIAsync* iSendDTMF;
	/**
	Active object which demonstrates the use of CTelephony::DialNewCall()
	*/
	CISVAPIAsync* iDialCall;
	/**
	Active object which demonstrates the use of CTelephony::HangUp()
	*/
	CISVAPIAsync* iHangup;
	/**
	Active object which demonstrates the use of CTelephony::GetCallStatus()
	*/
	CISVAPIAsync* iCallStatus;
	/**
	Active object which demonstrates the use of CTelephony::GetLineStatus()
	*/
	CISVAPIAsync* iLineStatus;
	/**
	Call ID of the currently active call.
	*/
	CTelephony::TCallId iCallId;
	/**
	The current single tone the user has specified.
	*/
	TBuf<1> iCurrentTone;
	/**
	A log of all tones sent down the line.
	*/
	TBuf<100> iCurrentToneLog;
	/**
	The number to be sent as a whole DTMF string.
	*/
	TBuf<100> iTheNumber;
	/**
	Has the user selected to enter the DTMF as a single string all
	in one go or as single characters.
	*/
	TBool iSingleString;
	};

#endif // __CMAINMENU_H__
