/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/



#include "CIdentityServiceStatus.h"

/**
Factory constructor.

@param  aController Pointer to MExecAsync object passed to constructor of 
                    CISVAPIBase
@return             Instance of CIdentityServiceStatus class
*/
CIdentityServiceStatus* CIdentityServiceStatus::NewL(MExecAsync* aController)
	{
	CIdentityServiceStatus* self = new(ELeave) CIdentityServiceStatus(aController);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);
	return self;
	}

/**
Destructor.
Cancels outstanding requests.
*/
CIdentityServiceStatus::~CIdentityServiceStatus()
	{
	Cancel();
	}

/**
Gets the identity service status and stores it in the iIdentityServiceStatusV1Pckg package.
*/
void CIdentityServiceStatus::DoStartRequestL()
	{
	_LIT(KDummyAnswerPanic, "CIdentityServiceStatus Get Method");
	__ASSERT_ALWAYS(!IsActive(), User::Panic(KDummyAnswerPanic, 1));
	iRequestNotify = EFalse;
	CTelephony::TIdentityService condition = CTelephony::EIdServiceCallerPresentation;
	
	// Interrogate the current status of the identity services.
	iTelephony->GetIdentityServiceStatus(	iStatus,
											condition,
											iIdentityServiceStatusV1Pckg);
	SetActive();
	}

/**
Constructor.

@param aController Pointer to an MExecAsync object passed to constructor of
                   CISVAPIBase.
*/
CIdentityServiceStatus::CIdentityServiceStatus(MExecAsync* aController)
	: CISVAPIAsync(aController, KIdentityServiceStatus),
	  iIdentityServiceStatusV1Pckg(iIdentityServiceStatusV1)
	{
	//
	}

/**
Second phase constructor.
*/
void CIdentityServiceStatus::ConstructL()
	{
	// Empty method
	}

/**
Checks the status of the active object and prints the identity service status
to the console if there is no error.
*/
void CIdentityServiceStatus::RunL()
	{
	if(iStatus != KErrNone)
		{
		iConsole->Printf(KError);
		
		// Print the error status code
		iConsole->Printf(_L("%d\n"), iStatus.Int());
		}
	else
		{
		// Print the console output message if there is no error
		iConsole->Printf(KIdentityServiceStatusMsg);
		switch(iIdentityServiceStatusV1.iIdentityStatus)
			{
		case CTelephony::EIdServiceActivePermanent:
		case CTelephony::EIdServiceActiveDefaultAllowed:
			iConsole->Printf(_L("Incoming Callers number Displayed\n"));
			break;
		case CTelephony::EIdServiceActiveDefaultRestricted:
		case CTelephony::EIdServiceNotProvisioned:
		case CTelephony::EIdServiceUnknown:
			iConsole->Printf(_L("Incoming Caller's number NOT Displayed\n"));
			break;
			}
		}
	ExampleComplete();
	}

/**
Cancels the asynchronous request to CTelephony::GetIdentityServiceStatus().
*/
void CIdentityServiceStatus::DoCancel()
	{
	// Cancels an outstanding asynchronous request.
	iTelephony->CancelAsync(CTelephony::EGetIdentityServiceStatusCancel);
	}
