/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/


#include "CAnswerIncomingCall.h"

/**
Factory constructor.

@param  aController Pointer to MExecAsync object passed to constructor of 
                    CISVAPIBase
@return             Instance of CAnswerIncomingCall class
*/
CAnswerIncomingCall* CAnswerIncomingCall::NewL(MExecAsync* aController)
	{
	CAnswerIncomingCall* self = new(ELeave) CAnswerIncomingCall(aController);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);
	return self;
	}

/**
Destructor.
Cancels outstanding requests.
*/
CAnswerIncomingCall::~CAnswerIncomingCall()
	{
	Cancel();
	}

/**
Answers the call specified in iCallId.
*/
void CAnswerIncomingCall::DoStartRequestL()
	{
	_LIT( KNotifyPanic, "CAnswerIncomingCall Get Method" );
	__ASSERT_ALWAYS( !IsActive(), User::Panic( KNotifyPanic, 1 ));
	iRequestNotify = EFalse;
	
	// Answers an incoming new voice call.
	iTelephony->AnswerIncomingCall(iStatus, iCallId);
	SetActive();
	}

/**
Constructor.

@param aController Pointer to an MExecAsync object passed to constructor of 
                   CISVAPIBase
*/
CAnswerIncomingCall::CAnswerIncomingCall(MExecAsync* aController)
	: CISVAPIAsync(aController, KAnswerIncomingCall),
	  iCallStatusV1Pckg( iCallStatusV1 )
	{
	// Empty method
	}

/**
Second phase constructor.
*/
void CAnswerIncomingCall::ConstructL()
	{
	iRequestNotify = EFalse;
	}

/**
Checks the status of the active object and if there is no error, tells the
user via the console that the call has been answered.
*/
void CAnswerIncomingCall::RunL()
	{
	if(iStatus != KErrNone)
		{
		iConsole->Printf(KError);
		
		// Print error status code
		iConsole->Printf(_L("%d\n"), iStatus.Int());
		}
	else
		{
		// Print the output to console if no error
		iConsole->Printf(_L("Call Answered ....\n"));
		ExampleComplete();
		}
	}

/**
Cancels asynchronous request to CTelephony::AnswerIncomingCall().
*/
void CAnswerIncomingCall::DoCancel()
	{
	// Cancels an outstanding asynchronous request.
	iTelephony->CancelAsync(CTelephony::EAnswerIncomingCallCancel);
	}

