/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/


#include "CDynamicCaps.h"

/**
Factory constructor.
@param aController Pointer to MExecAsync object
passed to constructor of CISVAPIBase
@param aCallId Identifies the call whose capabilities will be interrogated
@return Instance of CDynamicCaps class
*/
CDynamicCaps* CDynamicCaps::NewL(MExecAsync* aController, CTelephony::TCallId aCallId)
	{
	CDynamicCaps* self = new(ELeave) CDynamicCaps(aController, aCallId);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);
	return self;
	}

/**
Destructor.
Cancels outstanding requests
*/
CDynamicCaps::~CDynamicCaps()
	{
	Cancel();
	}

/**
Gets the dynamic call capabilities of the call identified by iCallId
and stores the results in the iCallCapsV1Pckg package.
*/
void CDynamicCaps::StartRequestL()
	{
	_LIT(KDummyAnswerPanic, "CDynamicCaps Get Method");
	__ASSERT_ALWAYS(!IsActive(), User::Panic(KDummyAnswerPanic, 1));
	iRequestNotify = EFalse;
	iTelephony->GetCallDynamicCaps(iCallId, iCallCapsV1Pckg);
	if( iCallCapsV1.iControlCaps & CTelephony::KCapsHold )
		{
		gConsole->Printf(_L("Call can be put on hold\n"));
		ExampleNotify();
		}
	else
		{
		gConsole->Printf(_L("Call cannot be put on hold\n"));
		// Code in CDynamicCaps::StartRequestL() needs to be finished
		//
		// do some thing!
		//
		}
	}

/**
Constructor.
@param aController Pointer to an MExecAsync object passed to
constructor of CISVAPIBase
@param aCallId Identifies the call whose capabilities will be interrogated
*/
CDynamicCaps::CDynamicCaps(MExecAsync* aController, CTelephony::TCallId aCallId)
	: CISVAPIAsync(aController)
	, iCallCapsV1Pckg(iCallCapsV1)
	, iCallId(aCallId)
	{
	iExtensionId = KDynamicCaps;
	}

/**
Second phase constructor.
*/
void CDynamicCaps::ConstructL()
	{
 	CActiveScheduler::Add(this);
	}

/**
Code in CDynamicCaps::RunL() needs to be written, empty method at present
*/
void CDynamicCaps::RunL()
	{

	}

/**
Code in CDynamicCaps::DoCancel() needs to be written, empty method at present
*/
void CDynamicCaps::DoCancel()
	{

	}

