/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/



#include "CNetworkRegInfo.h"

/**
Factory constructor.

@param  aController Pointer to MExecAsync object passed to constructor of 
                    CISVAPIBase
@return             Instance of CNetworkRegInfo class
*/
CNetworkRegInfo* CNetworkRegInfo::NewL(MExecAsync* aController)
	{
	CNetworkRegInfo* self = new(ELeave) CNetworkRegInfo(aController);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);
	return self;
	}

/**
Destructor.
*/
CNetworkRegInfo::~CNetworkRegInfo()
	{
	Cancel();
	}

/**
Gets the network registration status and stores it in the iNetworkRegV1Pckg 
package.
*/
void CNetworkRegInfo::DoStartRequestL()
	{
    iRequestNotify = EFalse;
   
    // Retrieves the current network registration status
	iTelephony->GetNetworkRegistrationStatus(iStatus, iNetworkRegV1Pckg);
	SetActive();
	}

/**
Constructor.

@param aController Pointer to an MExecAsync object passed to constructor of
                   CISVAPIBase
*/
CNetworkRegInfo::CNetworkRegInfo(MExecAsync* aController)
	: CISVAPIAsync(aController, KNetworkRegInfo),
	  iNetworkRegV1Pckg(iNetworkRegV1)
	{
	// Empty method
	}

/**
Second phase constructor.
*/
void CNetworkRegInfo::ConstructL()
	{
	iRequestNotify = EFalse;
	}

/**
Checks status of the active object and prints the network registration status
to the console.
*/
void CNetworkRegInfo::RunL()
	{
	if(iStatus != KErrNone)
		{
		iConsole->Printf(KError);
		
		// Print the output to console if there is no error
		iConsole->Printf(_L("%d\n"), iStatus.Int());
		}
	else
		{
		TBuf<30> theStatus;
		iConsole->Printf(KNetworkRegMsg);
		switch(iNetworkRegV1.iRegStatus)
			{
		case CTelephony::ERegistrationUnknown:
			theStatus.Append(_L("ERegistrationUnknown\n"));
			break;
		case CTelephony::ENotRegisteredNoService:
			theStatus.Append(_L("ENotRegisteredNoService\n"));
			break;
		case CTelephony::ENotRegisteredEmergencyOnly:
			theStatus.Append(_L("ENotRegisteredEmergencyOnly\n"));
			break;
		case CTelephony::ENotRegisteredSearching:
			theStatus.Append(_L("ENotRegisteredSearching\n"));
			break;
		case CTelephony::ERegisteredBusy:
			theStatus.Append(_L("ERegisteredBusy\n"));
			break;
		case CTelephony::ERegisteredOnHomeNetwork:
			theStatus.Append(_L("ERegisteredOnHomeNetwork\n"));
			break;
		case CTelephony::ERegistrationDenied:
			theStatus.Append(_L("ERegistrationDenied\n"));
			break;
		case CTelephony::ERegisteredRoaming:
			theStatus.Append(_L("ERegisteredRoaming\n"));
			break;
		default:
			break;
	 		}
		iConsole->Printf(theStatus);
		}
	if (iNetworkRegV1.iRegStatus == CTelephony::ERegisteredOnHomeNetwork)
		{
		ExampleNotify();
		}
	else
		{
		RequestNotificationL();
		}
	}

/**
Requests to receive notifications of changes in the network registration
status.
*/
void CNetworkRegInfo::DoRequestNotificationL()
	{
	// Panic if this object is already performing an asynchronous operation.
	// Application will panic if you call SetActive() on an already active object.
	_LIT( KNotifyPanic, "CNetworkReg Notify Method" );
	__ASSERT_ALWAYS( !IsActive(), User::Panic( KNotifyPanic, 1 ));
	iRequestNotify = ETrue;
	
	// Registers interest in receiving change notifications for events.
	iTelephony->NotifyChange(	iStatus,
								CTelephony::ENetworkRegistrationStatusChange,
								iNetworkRegV1Pckg );
	SetActive();
	}
	
/**
Cancels asynchronous request to CTelephony::GetNetworkRegistrationStatus()
*/
void CNetworkRegInfo::DoCancel()
	{
	iRequestNotify = EFalse;
	
	// Cancels an outstanding asynchronous request
	iTelephony->CancelAsync(CTelephony::ENetworkRegistrationStatusChangeCancel);
	}
