/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/


#include "CISVAPIBase.h"

/**
Default constructor.

@param aController  iController is set to point to this object
@param aExampleType The type of the derived class that has extended the 
                    functionality of this class
*/
CISVAPIBase::CISVAPIBase(MExecController* aController, TTelISVExampleType aExampleType)
	: CActive(EPriorityStandard),
	  iController(aController),
	  iExampleType(aExampleType)
	{
	CActiveScheduler::Add(this);
	RetrieveConsole();
	RetrieveTelephonyObject();
	}

/**
Makes a request for notification on changes to specified Etel 3rd party data.
*/
void CISVAPIBase::RequestNotificationL()
	{
	DoRequestNotificationL();
	}

/**
Virtual function for completing the notification request.  Empty method.
*/
void CISVAPIBase::DoRequestNotificationL()
	{
	/*
	 Implement CISVAPIBase::DoRequestNotificationL() in any derived
	     classes if required
	*/
	}

/**
Make an Etel 3rd Party request and wait for its completion.
*/
void CISVAPIBase::StartRequestL()
	{
	DoStartRequestL();
	}

/**
Virtual function for completing the request to start. Empty method.
*/
void CISVAPIBase::DoStartRequestL()
	{
	/*
	 Implement CISVAPIBase::DoStartRequestL() in any derived classes if 
	     required
	*/
	}

/**
As StartRequestL()

@param aCallId A call identifier to perform Etel Third Party operations on
*/
void CISVAPIBase::StartRequestL(CTelephony::TCallId aCallId)
	{
	DoStartRequestL(aCallId);
	}

/**
Virtual function for completing the request to start. Empty method.

@param aCallId A call identifier to perform Etel Third Party operations on
*/
void CISVAPIBase::DoStartRequestL(CTelephony::TCallId /*aCallId*/)
	{
	/*
	 Implement CISVAPIBase::DoStartRequestL(CTelephony::TCallId aCallId)
	     in any derived classes if required
	*/
	}

/**
As StartRequestL()

@param aTones A descriptor to perform Etel third party operations with
*/
void CISVAPIBase::StartRequestL(const TDesC& aTones)
	{
	DoStartRequestL(aTones);
	}

/**
Virtual function for completing the request to start. Empty method.

@param aNumber Number to be used
*/
void CISVAPIBase::DoStartRequestL(const TDesC& /*aNumber*/)
	{
	/*
	 Implement CISVAPIBase::DoStartRequestL(const TDesC& aNumber) in any 
	     derived classes if required
	*/
	}

/**
As StartRequestL()

@param aCallId1 A call identifier to perform Etel Third Party operations on
@param aCallId2 A call identifier to perform Etel Third Party operations on
*/
void CISVAPIBase::StartRequestL(CTelephony::TCallId aCallId1,
	                               CTelephony::TCallId aCallId2)
	{
	DoStartRequestL(aCallId1, aCallId2);
	}

/**
Virtual function for completing the request to start. Empty method.

@param aCallId1 A call identifier to perform Etel Third Party operations on
@param aCallId2 A call identifier to perform Etel Third Party operations on
*/
void CISVAPIBase::DoStartRequestL(CTelephony::TCallId /*aCallId1*/,
	                              CTelephony::TCallId /*aCallId2*/)
	{
	/*
	 Implement CISVAPIBase::DoStartRequestL(CTelephony::TCallId aCallId1, 
	     CTelephony::TCallId aCallId2) in any derived classes if required
	*/
	}

/**
Ends the execution of the application by stopping the active scheduler and 
cancelling any outstanding requests.
*/
void CISVAPIBase::AppTerminate()
	{
	iController->Terminate();
	}

