/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/



#include "TelephonyISVExamples.h"
#include "CMainMenu.h"

/**
Real main function.
*/
void MainL(CConsoleBase& aConsole)
	{
	CMainMenu* menu = CMainMenu::NewLC(aConsole);
	menu->Start();
	
	// Start the active scheduler
	CActiveScheduler::Start();
	CleanupStack::PopAndDestroy(menu);
	}

/**
Console harness.
*/
void ConsoleMainL()
	{
	// Get a console
	CConsoleBase* aConsole = Console::NewL(_L("Telephony ISV API Example"),
	                                       TSize(KConsFullScreen,
	                                       KConsFullScreen));
	CleanupStack::PushL(aConsole);
	CActiveScheduler* sched = new(ELeave) CActiveScheduler();
	
	// Push the active scheduler object onto the cleanup stack.
	CleanupStack::PushL(sched);
	
	// Install active scheduler
	CActiveScheduler::Install(sched);

	// Call function
	MainL(*aConsole);

	aConsole->Printf(_L("[ Press any key to end ]"));
	aConsole->Getch();
	
	// Finished with console
	CleanupStack::PopAndDestroy(sched);
	CleanupStack::PopAndDestroy(aConsole);
	}

/**
Cleanup stack harness.
*/
GLDEF_C TInt E32Main()
	{
	__UHEAP_MARK;
	CTrapCleanup* cleanupStack = CTrapCleanup::New();
	TRAPD(error, ConsoleMainL());
	__ASSERT_ALWAYS(!error, User::Panic(_L("Console main error\n"), error));
	delete cleanupStack;
	__UHEAP_MARKEND;
	return KErrNone;
	}

