/*
Copyright (c) 2005-2010 Nokia Corporation and/or its subsidiary(-ies). All rights reserved.

Redistribution and use in source and binary forms, with or without
modification, are permitted provided that the following conditions are met:

* Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer.
* Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution.
* Neither the name of Nokia Corporation nor the names of its contributors
 may be used to endorse or promote products derived from this software
 without specific prior written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE
FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR
SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER
CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

Description: 
*/



#include "CCallBarringStatus.h"

/**
Factory constructor.

@param  aController Pointer to MExecAsync object passed to constructor of 
                    CISVAPIBase
@return             Instance of CCallBarringStatus class
*/
CCallBarringStatus* CCallBarringStatus::NewL(MExecAsync* aController)
	{
	CCallBarringStatus* self = new(ELeave) CCallBarringStatus(aController);
	CleanupStack::PushL(self);
	self->ConstructL();
	CleanupStack::Pop(self);
	return self;
	}

/**
Destructor.
Calls Cancel() to cancel outstanding requests.
*/
CCallBarringStatus::~CCallBarringStatus()
	{
	Cancel();
	}

/**
Gets the current call barring status and stores result in 
iCallBarringStatusV1Pckg.
*/
void CCallBarringStatus::DoStartRequestL()
	{
	_LIT( KNotifyPanic, "CCallBarringStatus Get Method" );
	__ASSERT_ALWAYS( !IsActive(), User::Panic( KNotifyPanic, 1 ));
	iRequestNotify = EFalse;
	CTelephony::TCallBarringCondition condition = CTelephony::EBarAllIncoming;
	
	// Interrogate the current status of the call barring services.
	iTelephony->GetCallBarringStatus(	iStatus,
								     	condition,
								     	iCallBarringStatusV1Pckg);
	SetActive();
	}

/**
Constructor.

@param aController Pointer to an MExecAsync object passed to constructor of 
CISVAPIBase.
*/
CCallBarringStatus::CCallBarringStatus(MExecAsync* aController)
	: CISVAPIAsync(aController, KCallBarringStatus),
	  iCallBarringStatusV1Pckg(iCallBarringStatusV1)
	{
	// Empty method
	}

/**
Second phase constructor.
*/
void CCallBarringStatus::ConstructL()
	{
	// Empty method
	}

/**
Checks the status of the active object and displays the retrieved call barring
status if there is no error.
*/
void CCallBarringStatus::RunL()
	{
	if(iStatus != KErrNone)
		{
		iConsole->Printf(KError);
		
		// Print the error status code
		iConsole->Printf(_L("%d\n"), iStatus.Int());
		}
	else
		{
		// Print the output to the console if there is no error.
		iConsole->Printf(KCallBarringStatusMsg);
		switch(iCallBarringStatusV1.iCallBarring)
			{
		case CTelephony::EStatusActive:
			iConsole->Printf(_L("Call barring status is active.\n"));
			break;
		case CTelephony::ENotActive:
			iConsole->Printf(_L("Call barring status is not active.\n"));
			break;
		case CTelephony::ENotProvisioned:
			iConsole->Printf(_L("Call barring status is not provisioned.\n"));
			break;
		case CTelephony::ENotAvailable:
			iConsole->Printf(_L("Call barring status is not available.\n"));
			break;
		case CTelephony::EUnknown:
		default:
			iConsole->Printf(_L("Call barring status is unknown.\n"));
			break;
			}
		}
	ExampleComplete();
	}

/**
Cancels the asynchronous request to CTelephony::GetCallBarringStatus().
*/
void CCallBarringStatus::DoCancel()
	{
	// Cancels an outstanding asynchronous request.
	iTelephony->CancelAsync(CTelephony::EGetCallBarringStatusCancel);
	}

